
.. _index:

=======
Resolwe
=======

Resolwe is an open source dataflow package for `Django framework`_. It offers a
complete RESTful API to connect with external resources. A higher layer of
convenience APIs for JavaScript, Python and R are in development. A collection
of bioinformatics pipelines is available within the `Resolwe Bioinformatics`_
project. We envision a similar toolkit for machine learning.

.. _Django framework: https://www.djangoproject.com
.. _Resolwe Bioinformatics: https://github.com/genialis/resolwe-bio

.. figure:: images/resolwe_01_context.png

Contents
========

.. toctree::
   :maxdepth: 2

   overview
   intro
   proc
   api
   composer
   ref
   flow
   CHANGELOG
   contributing
